pub struct Ec2Service { /* private fields */ }Expand description
Amazon EC2 service.
Implementations
Sourceimpl Ec2Service
impl Ec2Service
Sourcepub fn with_state(state: SharedEc2State) -> Self
pub fn with_state(state: SharedEc2State) -> Self
Construct a service over a shared state handle (used by the server so persistence/snapshots can be wired in later batches).
Clone the shared state handle so the server can expose read-only
introspection endpoints (GET /_fakecloud/ec2/instances).